# -*- coding: utf-8 -*-
## AttchmentField
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
AttchmentField
"""
__version__ = "$Revision: 26418 $"
# $Source: /cvsroot/ingeniweb/PloneSubscription/SubscriptionTool.py,v $
# $Id: AttachmentFieldTool.py 26418 2006-07-25 14:09:18Z manuco $
__docformat__ = 'restructuredtext'


# Python imports
from StringIO import StringIO
import os

# Zope imports
from AccessControl import ClassSecurityInfo
from OFS.PropertyManager import PropertyManager
from OFS.SimpleItem import SimpleItem
from Products.CMFCore.utils import UniqueObject
from Globals import InitializeClass
from Products.PageTemplates.PageTemplateFile import PageTemplateFile

# CMF imports
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.ActionProviderBase import ActionProviderBase

# Other imports
import AttachmentService
import AttachmentField
import FlexStorage

_www = os.path.join(os.path.dirname(__file__), 'www')

class AttachmentFieldTool(
    UniqueObject,
    AttachmentService.AttachmentService,
    PropertyManager,
):
    """
    AttachmentFieldTool tool
    """

    id = 'portal_attachment'
    meta_type = 'AttachmentField Tool'
    security = ClassSecurityInfo()

    _properties = (
        {
            'id'  : 'contentDisposition',
            'type': 'selection',
            'mode': 'w',
            'select_variable' : 'getAvailableContentDisposition',
        },
    )

    manage_options = (
        AttachmentService.AttachmentService.manage_options +
        PropertyManager.manage_options
    )

    security.declarePrivate('manage_afterAdd')
    def manage_afterAdd(self, item, container):
        return self.migrate()


    security.declareProtected(CMFCorePermissions.ManagePortal, "migrate")
    def migrate(self):
        """
            Check that all properties are present and correctly initialized.
            If not, install them with a safe default value.
            It is safe to call it multiple times.
        """
        checkFor = [
            ("contentDisposition", self.getAvailableContentDisposition()[0]),
            ("currentFlexStorageBackend", "AttributeStorage"), ## ZODB
        ]
        rValue = ""
        for attr, default in checkFor:
            if not hasattr(self, attr):
                setattr(self, attr, default)
                rValue += "Added: %s\n" % attr
        if rValue == "":
            return "Tool was already up to date."
        return rValue + "\nTool succesfully updated!"


    def getAvailableContentDisposition(self):
        return [
            "attachment",
            "inline"
        ]

    def getAvailableFlexStorageBackends(self):
        ## FlexStorage object is not singleton and doesn't hold any properties
        ## of it's own. It is safe to build on the fly instances without damage.
        return FlexStorage.FlexStorage().getAvailableFlexStorages()

    def getSample(self, type):
        sampleLinks = {
            "attachment": self.absolute_url() + "/sample/contentDispositionAttachment",
            "inline": self.absolute_url() + "/sample/contentDispositionInline",
        }
        return sampleLinks[type]

    def getContentDisposition(self):
        return self.contentDisposition

    def getCurrentFlexStorageBackend(self):
        return self.currentFlexStorageBackend

    def setCurrentFlexStorageBackend(self, newStorageName):
        ## FlexStorage object is not singleton and doesn't hold any properties
        ## of it's own. It is safe to build on the fly instances without damage.
        FlexStorage.FlexStorage().changeFlexStorageBackend(
            self,
            newStorageName,
            AttachmentField.getContentTypesWithAttachmentFields(self)
        )


##    manage_options=(
##        (
##        { 'label' : 'Overview'
##        , 'action' : 'manage_overview'
##        },
##        ) +
##        ActionProviderBase.manage_options +
##        PropertyManager.manage_options +
##        SimpleItem.manage_options
##        )

    #
    #   ZMI methods
    #


InitializeClass(AttachmentFieldTool)
